@@ -212,7 +212,6 @@ Array <- R6::R6Class("Array",
                 return('')
 
             v <- paste0('\n ', base::toupper(self$title), '\n', v)
-            Encoding(v) <- 'UTF-8'
             v
         },
         .lookup=function(path) {
@@ -285,7 +284,7 @@ Array <- R6::R6Class("Array",
             if ( ! is.null(private$.header) && arrayPB$hasHeader)
                 private$.header$fromProtoBuf(arrayPB$header, oChanges, vChanges)
         },
-        asProtoBuf=function(incAsText=FALSE, status=NULL) {
+        asProtoBuf=function(incAsText=FALSE, status=NULL, includeState=TRUE) {
 
             arrayPB <- RProtoBuf_new(jamovi.coms.ResultsArray)
             if (identical(private$.layout, 'listSelect'))
@@ -294,12 +293,12 @@ Array <- R6::R6Class("Array",
                 arrayPB$hideHeadingOnlyChild <- TRUE
 
             for (item in private$.items)
-                arrayPB$add("elements", item$asProtoBuf(incAsText=incAsText, status=status))
+                arrayPB$add("elements", item$asProtoBuf(incAsText=incAsText, status=status, includeState=includeState))
 
-            result <- super$asProtoBuf(incAsText=incAsText, status=status)
+            result <- super$asProtoBuf(incAsText=incAsText, status=status, includeState=includeState)
             if ( ! is.null(private$.header)) {
                 arrayPB$hasHeader <- TRUE
-                arrayPB$header <- private$.header$asProtoBuf(incAsText=incAsText, status=status)
+                arrayPB$header <- private$.header$asProtoBuf(incAsText=incAsText, status=status, includeState=includeState)
             }
             result$array <- arrayPB
             result
